instrumenttools
===============

.. automodule:: abjad.tools.instrumenttools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.instrumenttools.Accordion.Accordion
      ~abjad.tools.instrumenttools.AltoFlute.AltoFlute
      ~abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone
      ~abjad.tools.instrumenttools.AltoTrombone.AltoTrombone
      ~abjad.tools.instrumenttools.AltoVoice.AltoVoice
      ~abjad.tools.instrumenttools.BaritoneSaxophone.BaritoneSaxophone
      ~abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice
      ~abjad.tools.instrumenttools.BassClarinet.BassClarinet
      ~abjad.tools.instrumenttools.BassFlute.BassFlute
      ~abjad.tools.instrumenttools.BassSaxophone.BassSaxophone
      ~abjad.tools.instrumenttools.BassTrombone.BassTrombone
      ~abjad.tools.instrumenttools.BassVoice.BassVoice
      ~abjad.tools.instrumenttools.Bassoon.Bassoon
      ~abjad.tools.instrumenttools.Cello.Cello
      ~abjad.tools.instrumenttools.ClarinetInA.ClarinetInA
      ~abjad.tools.instrumenttools.ClarinetInBFlat.ClarinetInBFlat
      ~abjad.tools.instrumenttools.ClarinetInEFlat.ClarinetInEFlat
      ~abjad.tools.instrumenttools.Contrabass.Contrabass
      ~abjad.tools.instrumenttools.ContrabassClarinet.ContrabassClarinet
      ~abjad.tools.instrumenttools.ContrabassFlute.ContrabassFlute
      ~abjad.tools.instrumenttools.ContrabassSaxophone.ContrabassSaxophone
      ~abjad.tools.instrumenttools.Contrabassoon.Contrabassoon
      ~abjad.tools.instrumenttools.EnglishHorn.EnglishHorn
      ~abjad.tools.instrumenttools.Flute.Flute
      ~abjad.tools.instrumenttools.FrenchHorn.FrenchHorn
      ~abjad.tools.instrumenttools.Glockenspiel.Glockenspiel
      ~abjad.tools.instrumenttools.Guitar.Guitar
      ~abjad.tools.instrumenttools.Harp.Harp
      ~abjad.tools.instrumenttools.Harpsichord.Harpsichord
      ~abjad.tools.instrumenttools.Instrument.Instrument
      ~abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory
      ~abjad.tools.instrumenttools.InstrumentationSpecifier.InstrumentationSpecifier
      ~abjad.tools.instrumenttools.Marimba.Marimba
      ~abjad.tools.instrumenttools.MezzoSopranoVoice.MezzoSopranoVoice
      ~abjad.tools.instrumenttools.Oboe.Oboe
      ~abjad.tools.instrumenttools.Performer.Performer
      ~abjad.tools.instrumenttools.PerformerInventory.PerformerInventory
      ~abjad.tools.instrumenttools.Piano.Piano
      ~abjad.tools.instrumenttools.Piccolo.Piccolo
      ~abjad.tools.instrumenttools.SopraninoSaxophone.SopraninoSaxophone
      ~abjad.tools.instrumenttools.SopranoSaxophone.SopranoSaxophone
      ~abjad.tools.instrumenttools.SopranoVoice.SopranoVoice
      ~abjad.tools.instrumenttools.TenorSaxophone.TenorSaxophone
      ~abjad.tools.instrumenttools.TenorTrombone.TenorTrombone
      ~abjad.tools.instrumenttools.TenorVoice.TenorVoice
      ~abjad.tools.instrumenttools.Trumpet.Trumpet
      ~abjad.tools.instrumenttools.Tuba.Tuba
      ~abjad.tools.instrumenttools.UntunedPercussion.UntunedPercussion
      ~abjad.tools.instrumenttools.Vibraphone.Vibraphone
      ~abjad.tools.instrumenttools.Viola.Viola
      ~abjad.tools.instrumenttools.Violin.Violin
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering
      ~abjad.tools.instrumenttools.Xylophone.Xylophone

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.instrumenttools.iterate_out_of_range_notes_and_chords.iterate_out_of_range_notes_and_chords
      ~abjad.tools.instrumenttools.notes_and_chords_are_in_range.notes_and_chords_are_in_range
      ~abjad.tools.instrumenttools.notes_and_chords_are_on_expected_clefs.notes_and_chords_are_on_expected_clefs
      ~abjad.tools.instrumenttools.transpose_from_sounding_pitch_to_written_pitch.transpose_from_sounding_pitch_to_written_pitch
      ~abjad.tools.instrumenttools.transpose_from_written_pitch_to_sounding_pitch.transpose_from_written_pitch_to_sounding_pitch
